Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(200)

Unified Diff: chrome/browser/android/vr_shell/color_scheme.h

Issue 2914623003: [VrShell] Centralize color handling and enable close button on fullscreen (Closed)
Patch Set: update fullscreen colors, try to get them to show up on mode switch Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/android/vr_shell/color_scheme.h
diff --git a/chrome/browser/android/vr_shell/color_scheme.h b/chrome/browser/android/vr_shell/color_scheme.h
index 9f14c5ac2959919a06a9eeba054759a00f44bc31..b8a507ddb0b652438e120b4ee35375aa48facd95 100644
--- a/chrome/browser/android/vr_shell/color_scheme.h
+++ b/chrome/browser/android/vr_shell/color_scheme.h
@@ -21,21 +21,22 @@ struct ColorScheme {
// These colors should be named generically, if possible, so that they can be
// meaningfully reused by multiple elements.
- SkColor horizon;
+ SkColor world_background;
cjgrant 2017/05/31 15:39:28 This more verbose naming looks great to me.
amp 2017/06/02 01:08:35 Acknowledged.
SkColor floor;
SkColor ceiling;
SkColor floor_grid;
// The foreground color is used for text and sometimes for icons.
- SkColor foreground;
- SkColor emphasized;
- SkColor deemphasized;
-
- // This is the background color. To be used behind text in the foreground
- // color. The related hover and down colors are to be used for buttons.
- SkColor background;
- SkColor background_hover;
- SkColor background_down;
+ SkColor element_foreground;
+ SkColor text_emphasized;
+ SkColor text_deemphasized;
+
+ // This is the element background color. To be used behind text or icons in
+ // the foreground color. The related hover and down colors are to be used for
+ // buttons.
+ SkColor element_background;
+ SkColor element_background_hover;
+ SkColor element_background_down;
// If you have a segmented element, its separators should use this color.
SkColor separator;

Powered by Google App Engine
This is Rietveld 408576698